PyRuster
========

Simple features
---------------

Implementing some syntax like rust:

- Option
- Result

Requirements
------------
``python: 3.6``

Installation
------------

.. code-block:: text

    pip install pyruster
